==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dc/de3/road__type_8h.js <==
var road__type_8h =
[
    [ "EnumPropsT< RoadType >", "d6/d00/structEnumPropsT_3_01RoadType_01_4.html", null ],
    [ "EnumPropsT< RoadTypes >", "d0/d7f/structEnumPropsT_3_01RoadTypes_01_4.html", null ],
    [ "EnumPropsT< RoadBits >", "dc/daf/structEnumPropsT_3_01RoadBits_01_4.html", null ],
    [ "RoadTypesByte", "dc/de3/road__type_8h.html#a4b693fb2ea9adc8915b1bb40fa928f5a", null ],
    [ "RoadBits", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0", [
      [ "ROAD_NONE", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a15c59580ffd7a5744f1595f85e07bfe2", null ],
      [ "ROAD_NW", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0aae6c4df48046796d4dd4ebea97af89ce", null ],
      [ "ROAD_SW", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a133d944e18259f4612f57091b5e10cf5", null ],
      [ "ROAD_SE", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a7ea6262a760c4d557e5cc504c0a029b7", null ],
      [ "ROAD_NE", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a4cf1b8ca2df535ac2a06da99c71a3b15", null ],
      [ "ROAD_X", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0acd957c2de9641b29a38e7c922ab9d33e", null ],
      [ "ROAD_Y", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a902a8a4667430a740f660050705a7df3", null ],
      [ "ROAD_N", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a7a4474171479e5cb9221af592c18dd49", null ],
      [ "ROAD_E", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a194eced412c50c5a470143e2dca29e9f", null ],
      [ "ROAD_S", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a947b01950e3389f1a5414ccfc56c9633", null ],
      [ "ROAD_W", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a9f28692dcbe4bf224e6ebd0872a8d0f8", null ],
      [ "ROAD_ALL", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a157c9128e32e38784fd121e79b3baae8", null ],
      [ "ROAD_END", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0ae71c377a028b7d85220c37a3ea9155ef", null ]
    ] ],
    [ "RoadType", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5", [
      [ "ROADTYPE_BEGIN", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5af9dba653c115b8e9d9d06099571ce6c3", null ],
      [ "ROADTYPE_ROAD", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5a8658087239017d16f1ade8f0d61a78ea", null ],
      [ "ROADTYPE_TRAM", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5a55eb75c7b9e5c138d7caf88d4ab1b321", null ],
      [ "ROADTYPE_END", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5ae4c236c558508a6caf155afcad8ee43e", null ],
      [ "INVALID_ROADTYPE", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5a2e32a4a8cf7105c2580db14a3315819c", null ]
    ] ],
    [ "RoadTypes", "dc/de3/road__type_8h.html#a6ac5ea4dc5311c39f52d1b617e7fdb31", [
      [ "ROADTYPES_NONE", "dc/de3/road__type_8h.html#a6ac5ea4dc5311c39f52d1b617e7fdb31ab3d69832b3b434da6079da3606eda146", null ],
      [ "ROADTYPES_ROAD", "dc/de3/road__type_8h.html#a6ac5ea4dc5311c39f52d1b617e7fdb31a7efa58da51049ed5707b6c1012482f7c", null ],
      [ "ROADTYPES_TRAM", "dc/de3/road__type_8h.html#a6ac5ea4dc5311c39f52d1b617e7fdb31a0a68a3fc2e6ab817d32c566aba74ceb9", null ],
      [ "ROADTYPES_ALL", "dc/de3/road__type_8h.html#a6ac5ea4dc5311c39f52d1b617e7fdb31a5a519dc8cafedda8291c72e561a78b57", null ],
      [ "ROADTYPES_END", "dc/de3/road__type_8h.html#a6ac5ea4dc5311c39f52d1b617e7fdb31a15131efe038132e4c568779f2083f631", null ],
      [ "INVALID_ROADTYPES", "dc/de3/road__type_8h.html#a6ac5ea4dc5311c39f52d1b617e7fdb31a1574a89c7b73de203117f534e8833bb3", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dc/de3/road__type_8h.js <==
var road__type_8h =
[
    [ "EnumPropsT< RoadType >", "d6/d00/structEnumPropsT_3_01RoadType_01_4.html", null ],
    [ "EnumPropsT< RoadBits >", "dc/daf/structEnumPropsT_3_01RoadBits_01_4.html", null ],
    [ "RoadTypeLabel", "dc/de3/road__type_8h.html#a4728698dba11eed9e1f65aeb3a25c9ac", null ],
    [ "RoadBits", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0", [
      [ "ROAD_NONE", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a15c59580ffd7a5744f1595f85e07bfe2", null ],
      [ "ROAD_NW", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0aae6c4df48046796d4dd4ebea97af89ce", null ],
      [ "ROAD_SW", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a133d944e18259f4612f57091b5e10cf5", null ],
      [ "ROAD_SE", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a7ea6262a760c4d557e5cc504c0a029b7", null ],
      [ "ROAD_NE", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a4cf1b8ca2df535ac2a06da99c71a3b15", null ],
      [ "ROAD_X", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0acd957c2de9641b29a38e7c922ab9d33e", null ],
      [ "ROAD_Y", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a902a8a4667430a740f660050705a7df3", null ],
      [ "ROAD_N", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a7a4474171479e5cb9221af592c18dd49", null ],
      [ "ROAD_E", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a194eced412c50c5a470143e2dca29e9f", null ],
      [ "ROAD_S", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a947b01950e3389f1a5414ccfc56c9633", null ],
      [ "ROAD_W", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a9f28692dcbe4bf224e6ebd0872a8d0f8", null ],
      [ "ROAD_ALL", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0a157c9128e32e38784fd121e79b3baae8", null ],
      [ "ROAD_END", "dc/de3/road__type_8h.html#a4f311f67b9752fd596075b657e72b7e0ae71c377a028b7d85220c37a3ea9155ef", null ]
    ] ],
    [ "RoadType", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5", [
      [ "ROADTYPE_BEGIN", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5af9dba653c115b8e9d9d06099571ce6c3", null ],
      [ "ROADTYPE_ROAD", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5a8658087239017d16f1ade8f0d61a78ea", null ],
      [ "ROADTYPE_TRAM", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5a55eb75c7b9e5c138d7caf88d4ab1b321", null ],
      [ "ROADTYPE_END", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5ae4c236c558508a6caf155afcad8ee43e", null ],
      [ "INVALID_ROADTYPE", "dc/de3/road__type_8h.html#a1468fbaca3a60ec4e7f24a9ac83ef2c5a2e32a4a8cf7105c2580db14a3315819c", null ]
    ] ],
    [ "RoadTypes", "dc/de3/road__type_8h.html#a060f27293ca5cad8c8e056fb9424e7ca", [
      [ "ROADTYPES_NONE", "dc/de3/road__type_8h.html#a060f27293ca5cad8c8e056fb9424e7caab3d69832b3b434da6079da3606eda146", null ],
      [ "ROADTYPES_ROAD", "dc/de3/road__type_8h.html#a060f27293ca5cad8c8e056fb9424e7caa7efa58da51049ed5707b6c1012482f7c", null ],
      [ "ROADTYPES_TRAM", "dc/de3/road__type_8h.html#a060f27293ca5cad8c8e056fb9424e7caa0a68a3fc2e6ab817d32c566aba74ceb9", null ],
      [ "INVALID_ROADTYPES", "dc/de3/road__type_8h.html#a060f27293ca5cad8c8e056fb9424e7caa1574a89c7b73de203117f534e8833bb3", null ]
    ] ]
];
